@@ -40,7 +40,7 @@ class BNPView;
  */
 class BasketPart : public KParts::ReadWritePart
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
