@@ -28,7 +28,7 @@
 //----------------------------
 extern "C"
 {
-	KDE_EXPORT TDECModule *create_basket_config_general(TQWidget *parent, const char *)
+	TDE_EXPORT TDECModule *create_basket_config_general(TQWidget *parent, const char *)
 	{
 		GeneralPage *page = new GeneralPage(parent, "kcmbasket_config_general");
 		return page;
@@ -37,7 +37,7 @@ extern "C"
 
 extern "C"
 {
-	KDE_EXPORT TDECModule *create_basket_config_baskets(TQWidget *parent, const char *)
+	TDE_EXPORT TDECModule *create_basket_config_baskets(TQWidget *parent, const char *)
 	{
 		BasketsPage *page = new BasketsPage(parent, "kcmbasket_config_baskets");
 		return page;
@@ -46,7 +46,7 @@ extern "C"
 
 extern "C"
 {
-	KDE_EXPORT TDECModule *create_basket_config_new_notes(TQWidget *parent, const char *)
+	TDE_EXPORT TDECModule *create_basket_config_new_notes(TQWidget *parent, const char *)
 	{
 		NewNotesPage *page = new NewNotesPage(parent, "kcmbasket_config_new_notes");
 		return page;
@@ -55,7 +55,7 @@ extern "C"
 
 extern "C"
 {
-	KDE_EXPORT TDECModule *create_basket_config_notes_appearance(TQWidget *parent, const char *)
+	TDE_EXPORT TDECModule *create_basket_config_notes_appearance(TQWidget *parent, const char *)
 	{
 		NotesAppearancePage *page = new NotesAppearancePage(parent, "kcmbasket_config_notes_appearance");
 		return page;
@@ -64,7 +64,7 @@ extern "C"
 
 extern "C"
 {
-	KDE_EXPORT TDECModule *create_basket_config_apps(TQWidget *parent, const char *)
+	TDE_EXPORT TDECModule *create_basket_config_apps(TQWidget *parent, const char *)
 	{
 		ApplicationsPage *page = new ApplicationsPage(parent, "kcmbasket_config_apps");
 		return page;
