@@ -65,7 +65,7 @@ class KGpgMe
 		TQString m_text;
 		bool m_saving;
 		bool m_useGnuPGAgent;
-		TQCString m_cache;
+		TQString m_cache;
 
 		void init(gpgme_protocol_t proto);
 		gpgme_error_t readToBuffer(gpgme_data_t in, TQByteArray* outBuffer) const;
