@@ -18,6 +18,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 
 #include <tdecmdlineargs.h>
@@ -46,10 +50,6 @@
 #include "basket_options.h"
 #include "backup.h"
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 /* Thanks to JuK for this Application class */
 /*#if KDE_IS_VERSION( 3, 1, 90 )
 typedef KUniqueApplication Application; // KDE 3.2 and later already re-show the main window
