@@ -18,7 +18,9 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
-#include "password.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #ifdef HAVE_LIBGPGME
 
@@ -32,6 +34,8 @@
 #include <kgpgme.h>
 #include <basket.h>
 
+#include "password.h"
+
 PasswordDlg::PasswordDlg(TQWidget *parent, const char *name)
 	:KDialogBase(Plain, i18n("Password Protection"), Ok|Cancel, Ok,
 				 parent, name, /*modal=*/true, /*separator=*/true), w(0)
